package net.wanji.common.enums;

import java.util.ArrayList;
import java.util.List;

/**
 * @author hfx
 * @date 2023/1/28 18:03
 * @desc 转向转换
 */
public enum TurnConvertEnum {

    /**
     * 车道转向转换转向类型：key 车道转向，code 转向类型，desc 描述
     * 车道转向：0未知；1左转；2直行；3右转；4掉头；5直左；6直右；7左直右；8左右；
     * 9左转掉头；10直行掉头；11右转掉头；12左直掉头；13直右掉头；14左直右掉头；15左右掉头
     */
    UNKNOWN(0, "unknown", "未知"),
    L(1, "l", "左转"),
    S(2, "s", "直行"),
    R(3, "r", "右转"),
    U(4, "u", "掉头"),
    L_S(5, "l_s", "直左"),
    S_R(6, "s_r", "直右"),
    L_S_R(7, "l_s_r", "左直右"),
    L_R(8, "l_r", "左右"),
    L_U(9, "l_u", "左转掉头"),
    S_U(10, "s_u", "直行掉头"),
    R_U(11, "r_u", "右转掉头"),
    L_S_U(12, "l_s_u", "左直掉头"),
    U_S_R(13, "u_s_r", "直右掉头"),
    L_S_R_U(14, "l_s_r_u", "左直右掉头"),
    L_R_U(15, "l_r_u", "左右掉头");

    private Integer key;
    private String code;
    private String desc;

    TurnConvertEnum(Integer key, String code, String desc){
        this.key = key;
        this.code = code;
        this.desc = desc;
    }

    public Integer getKey() {
        return key;
    }

    public String getCode() {
        return code;
    }

    public String getDesc() {
        return desc;
    }

    public static String getCodeByKey(Integer key){
        for (TurnConvertEnum e : TurnConvertEnum.values()) {
            if(e.key.equals(key)){
                return e.code;
            }
        }
        return null;
    }

    public static Integer getKeyByCode(String code){
        for (TurnConvertEnum e : TurnConvertEnum.values()) {
            if(e.code.equals(code)){
                return e.key;
            }
        }
        return null;
    }

    public static String getDescByCode(String code){
        for (TurnConvertEnum e : TurnConvertEnum.values()) {
            if(e.code.equals(code)){
                return e.desc;
            }
        }
        return null;
    }
    public static String getDescByKey(Integer key){
        for (TurnConvertEnum e : TurnConvertEnum.values()) {
            if(e.key.equals(key)){
                return e.desc;
            }
        }
        return null;
    }


    public static List<Integer> getKeyListBySingleCode(String singleCode){
        List<Integer> res = new ArrayList<>();
        for (TurnConvertEnum e : TurnConvertEnum.values()) {
            if(e.code.contains(singleCode)){
                res.add(e.key);
            }
        }
        return res;
    }

    public static String getCodeByDesc(String desc){
        for (TurnConvertEnum e : TurnConvertEnum.values()) {
            if(e.desc.equals(desc)){
                return e.code;
            }
        }
        return null;
    }

}
